@@ -6,7 +6,7 @@ import structlog
 import os
 from pathlib import Path
 
-import toml
+import tomli
 import pytest
 
 from nvchecker import core
@@ -38,7 +38,8 @@ async def run(
   result_coro = core.process_result(oldvers, result_q, entry_waiter)
   runner_coro = core.run_tasks(futures)
 
-  return await main.run(result_coro, runner_coro)
+  vers, _has_failures = await main.run(result_coro, runner_coro)
+  return vers
 
 @pytest.fixture(scope="module")
 async def get_version():
@@ -52,7 +53,7 @@ async def get_version():
 @pytest.fixture(scope="module")
 async def run_str():
   async def __call__(str):
-    entries = toml.loads(str)
+    entries = tomli.loads(str)
     newvers = await run(entries)
     return newvers.popitem()[1]
 
@@ -61,19 +62,19 @@ async def run_str():
 @pytest.fixture(scope="module")
 async def run_str_multi():
   async def __call__(str):
-    entries = toml.loads(str)
+    entries = tomli.loads(str)
     newvers = await run(entries)
     return newvers
 
   return __call__
 
+loop = asyncio.new_event_loop()
 @pytest.fixture(scope="session")
 def event_loop(request):
   """Override pytest-asyncio's event_loop fixture,
      Don't create an instance of the default event loop for each test case.
      We need the same ioloop across tests for the aiohttp support.
   """
-  loop = asyncio.get_event_loop()
   yield loop
 
 @pytest.fixture(scope="session", autouse=True)
